@@ -21,14 +21,14 @@
  * @param {object} tab
  */
 browser.tabs.onCreated.addListener((tab) => {
-    if (tab.id > 0) {
-        if (tab.selected) {
-            page.currentTabId = tab.id;
-            if (!page.tabs[tab.id]) {
-                page.createTabEntry(tab.id);
-            }
-            page.switchTab(tab);
+    if (tab?.id > 0 && tab?.selected) {
+        page.currentTabId = tab.id;
+
+        if (!page.tabs[tab.id]) {
+            page.createTabEntry(tab.id);
         }
+
+        page.switchTab(tab);
     }
 });
 
@@ -39,12 +39,8 @@ browser.tabs.onCreated.addListener((tab) => {
  */
 browser.tabs.onRemoved.addListener(async function(tabId, removeInfo) {
     if (page.currentTabId === tabId) {
-        const activeTabs = await browser.tabs.query({ active: true, currentWindow: true });
-        if (activeTabs.length > 0) {
-            page.currentTabId = activeTabs[0].id;
-        } else {
-            page.currentTabId = -1;
-        }
+        const currentTab = await getCurrentTab();
+        page.currentTabId = currentTab ? currentTab.id : -1;
     }
     delete page.tabs[tabId];
 });
@@ -97,8 +93,7 @@ browser.tabs.onUpdated.addListener((tabId, changeInfo, tab) => {
  * @param {object} details
  */
 browser.webNavigation.onCommitted.addListener((details) => {
-    if ((details.transitionQualifiers.length > 0 && details.transitionQualifiers[0] === 'client_redirect')
-        || details.transitionType === 'form_submit') {
+    if (details.transitionQualifiers?.[0] === 'client_redirect' || details.transitionType === 'form_submit') {
         page.redirectCount += 1;
         return;
     }
@@ -153,9 +148,9 @@ browser.commands.onCommand.addListener(async (command) => {
         || command === 'choose_credential_fields'
         || command === 'retrive_credentials_forced'
         || command === 'reload_extension') {
-        const tabs = await browser.tabs.query({ active: true, currentWindow: true });
-        if (tabs.length) {
-            browser.tabs.sendMessage(tabs[0].id, { action: command });
+        const tab = await getCurrentTab();
+        if (tab) {
+            browser.tabs.sendMessage(tab.id, { action: command });
         }
     }
 });
