@@ -29,11 +29,11 @@ const PREDEFINED_SITELIST = [
     'https://twitter.com/i/flow/login',
     'https://login3.id.hp.com/*',
     'https://secure.fnac.com/identity/server/gateway/*',
-    'https://*.openai.com/u/login/*'
+    'https://*.openai.com/u/login/*',
+    'https://www.patreon.com/login',
+    'https://*.wordpress.com/log-in/'
 ];
 
-const awsUrl = 'signin.aws.amazon.com';
-const ebayUrl = 'https://www.ebay.';
 const googleUrl = 'https://accounts.google.com';
 
 const kpxcSites = {};
@@ -58,9 +58,10 @@ kpxcSites.detectUsernameFromPage = function() {
  * Handles a few exceptions for certain sites where password form is inside a div
  * or another element that is not detected directly. Triggered by MutationObserver.
  * @param {string} identifier   Usually a classList or element id
+ * @param {object} field        The target element
  * @returns {boolean}           True if an Element has a match with the identifier and document location
  */
-kpxcSites.exceptionFound = function(identifier) {
+kpxcSites.exceptionFound = function(identifier, field) {
     if (!identifier || identifier.length === 0) {
         return;
     }
@@ -82,6 +83,10 @@ kpxcSites.exceptionFound = function(identifier) {
               || document.location.origin.startsWith('https://mail.protonmail.com')
               && identifier === 'mailboxPassword') {
         return true;
+    } else if (document.location.origin === 'https://www.patreon.com' && field?.name === 'current-password') {
+        return true;
+    } else if (document.location.origin === 'https://wordpress.com' && identifier?.value === 'login__form-password') {
+        return true;
     }
 
     return false;
@@ -151,14 +156,14 @@ kpxcSites.formSubmitButtonExceptionFound = function(form) {
         const buttons = findDiv.getElementsByTagName('button');
         kpxcSites.savedForm = form;
         return buttons.length > 0 ? buttons[0] : undefined;
-    } else if (form.action.startsWith(ebayUrl)) {
+    } else if (form.action.startsWith('https://www.ebay.')) {
         // For eBay we must return the first button.
         for (const i of form.elements) {
             if (i.type === 'button') {
                 return i;
             }
         }
-    } else if (form.action.includes(awsUrl)) {
+    } else if (form.action.includes('signin.aws.amazon.com')) {
         // For Amazon AWS the button is outside the form.
         const button = $('#signin_button');
         if (button) {
@@ -176,6 +181,9 @@ kpxcSites.formSubmitButtonExceptionFound = function(form) {
         if (buttons?.length > 1) {
             return buttons[1];
         }
+    } else if (form.action.startsWith('https://barmerid.id.bconnect.barmer.de')) {
+        const loginButton = $('#btn-login');
+        return loginButton?.shadowRoot?.children?.[0];
     }
 
     return undefined;
