@@ -195,10 +195,9 @@ kpxcFields.getAllPageInputs = async function(previousInputs = []) {
 /**
  * Returns the combination where input field is used
  * @param {HTMLElement} field Input field
- * @param {String} givenType 'username' or 'password'
+ * @param {String} givenType For example: 'username', 'password', 'totp', 'totpInputs'
  */
 kpxcFields.getCombination = async function(field, givenType) {
-    // If givenType is not set, return the combination that uses the selected field
     for (const combination of kpxc.combinations) {
         if (givenType) {
             // Strictly search a given type
@@ -302,7 +301,9 @@ kpxcFields.getElementFromXPathId = function(xpath) {
 kpxcFields.handleSegmentedTOTPFields = function(inputs, combinations) {
     // Check for multiple segmented TOTP fields when there are no inputs, or combination contains the segemented fields
     const segmentedFields = combinations.filter(c => c.totp);
-    if (combinations.length === 0 || segmentedFields.length === DEFAULT_SEGMENTED_TOTP_FIELDS) {
+    if (combinations.length === 0
+        || segmentedFields.length === DEFAULT_SEGMENTED_TOTP_FIELDS
+        || inputs?.length === DEFAULT_SEGMENTED_TOTP_FIELDS) {
         kpxcFields.getSegmentedTOTPFields(inputs, combinations);
     }
 
