@@ -153,8 +153,8 @@ kpxcUI.setIconPosition = function(icon, field, rtl = false, segmented = false) {
     const scrollLeft = kpxcUI.getScrollLeft();
     icon.style.top = Pixels(top + scrollTop + offset + 1);
     icon.style.left = rtl
-                    ? Pixels((left + scrollLeft) + offset)
-                    : Pixels(left + scrollLeft + field.offsetWidth - size - offset);
+        ? Pixels((left + scrollLeft) + offset)
+        : Pixels(left + scrollLeft + field.offsetWidth - size - offset);
 };
 
 kpxcUI.getScrollTop = function() {
@@ -251,6 +251,29 @@ kpxcUI.createNotification = function(type, message) {
         return;
     }
 
+    // Removes notification from the body element
+    const removeNotification = function() {
+        // Catch cross-domain exception
+        let parentBody;
+        try {
+            parentBody = window.parent.document.body;
+        } catch(e) {
+            parentBody = window.document.body;
+        }
+
+        if (notificationWrapper && parentBody.contains(notificationWrapper)) {
+            parentBody.removeChild(notificationWrapper);
+            notificationWrapper = undefined;
+            return;
+        }
+
+        // Notification is not in the parent
+        if (notificationWrapper && parentBody !== window.document.body && window.document.body.contains(notificationWrapper)) {
+            window.document.body.removeChild(notificationWrapper);
+            notificationWrapper = undefined;
+        }
+    };
+
     logDebug(message);
 
     const notification = kpxcUI.createElement('div', 'kpxc-notification kpxc-notification-' + type, {});
@@ -262,16 +285,14 @@ kpxcUI.createNotification = function(type, message) {
     const msg = kpxcUI.createElement('span', '', {}, message);
 
     notification.addEventListener('click', function() {
-        if (notificationWrapper && window.parent.document.body.contains(notificationWrapper)) {
-            window.parent.document.body.removeChild(notificationWrapper);
-            notificationWrapper = undefined;
-        }
+        removeNotification();
     });
 
     notification.appendMultiple(icon, label, msg);
 
     const styleSheet = createStylesheet('css/notification.css');
     notificationWrapper = notificationWrapper || document.createElement('div');
+    notificationWrapper.style.all = 'unset';
     notificationWrapper.style.display = 'none';
     styleSheet.addEventListener('load', () => notificationWrapper.style.display = 'block');
     this.shadowRoot = notificationWrapper.attachShadow({ mode: 'closed' });
@@ -289,10 +310,7 @@ kpxcUI.createNotification = function(type, message) {
 
     // Destroy the banner after five seconds
     notificationTimeout = setTimeout(() => {
-        if (notificationWrapper && window.parent.document.body.contains(notificationWrapper)) {
-            window.parent.document.body.removeChild(notificationWrapper);
-            notificationWrapper = undefined;
-        }
+        removeNotification();
     }, 5000);
 };
 
@@ -307,16 +325,11 @@ const DOMRectToArray = function(domRect) {
 };
 
 const initColorTheme = function(elem) {
-    const colorTheme = kpxc.settings['colorTheme'];
-
-    if (colorTheme === undefined) {
-        elem.removeAttribute('data-color-theme');
-    } else if (colorTheme === 'system') {
-        const theme = window.matchMedia('(prefers-color-scheme: dark)').matches ? 'dark' : 'light';
-        elem.setAttribute('data-color-theme', theme);
-    } else {
-        elem.setAttribute('data-color-theme', colorTheme);
+    let theme = kpxc.settings['colorTheme'];
+    if (theme === 'system') {
+        theme = window.matchMedia('(prefers-color-scheme: dark)').matches ? 'dark' : 'light';
     }
+    elem.setAttribute('data-bs-theme', theme);
 };
 
 const createStylesheet = function(file) {
