@@ -4,9 +4,6 @@ const $ = function(elem) {
     return document.querySelector(elem);
 };
 
-const DEFAULT_POPUP_SIZE = '460px';
-const PINNED_POPUP_SIZE = '380px';
-
 function updateAvailableResponse(available) {
     if (available) {
         $('#update-available').show();
@@ -36,19 +33,17 @@ async function initSettings() {
 }
 
 async function initColorTheme() {
-    const colorTheme = await browser.runtime.sendMessage({
+    let theme = await browser.runtime.sendMessage({
         action: 'get_color_theme'
     });
-
-    if (colorTheme === undefined || colorTheme === 'system') {
-        document.body.removeAttribute('data-color-theme');
-    } else {
-        document.body.setAttribute('data-color-theme', colorTheme);
+    if (theme === 'system') {
+        theme = window.matchMedia('(prefers-color-scheme: dark)').matches ? 'dark' : 'light';
     }
+    document.documentElement.setAttribute('data-bs-theme', theme);
 }
 
 async function getLoginData() {
-    const tab = getCurrentTab();
+    const tab = await getCurrentTab();
     if (!tab) {
         return [];
     }
@@ -60,22 +55,6 @@ async function getLoginData() {
     return logins;
 }
 
-// Sets default popup size for Chromium based browsers to prevent flash on popup open
-function setDefaultPopupSize() {
-    if (!isFirefox()) {
-        document.body.style.width = DEFAULT_POPUP_SIZE;
-    }
-}
-
-// Resizes the popup to the default size if the width is too small
-function resizePopup() {
-    if (document.body.offsetWidth > 0 && document.body.offsetWidth < 100) {
-        document.body.style.width = isFirefox() ? PINNED_POPUP_SIZE : DEFAULT_POPUP_SIZE;
-    } else {
-        document.body.style.width = DEFAULT_POPUP_SIZE;
-    }
-}
-
 (async () => {
     if (document.readyState === 'complete' || (document.readyState !== 'loading' && !document.documentElement.doScroll)) {
         await initSettings();
